@@ -104,7 +104,9 @@ def _parse_schema(schema, method):
         return _parse_schema(schema['oneOf'][0], method)
 
     if 'enum' in schema:
-        # we only show the first one since we can't show everything
+        if 'example' in schema:
+            return schema['example']
+        # we show the first one
         return schema['enum'][0]
 
     schema_type = schema.get('type', 'object')
@@ -134,7 +136,11 @@ def _parse_schema(schema, method):
                     for k, v in schema.get('properties', {}).items():
                         if v.get('readOnly', False):
                             del example[k]
-                return collections.OrderedDict(example)
+                ret = collections.OrderedDict(example)
+                if schema.get('additionalProperties', False) and '...' not in example:
+                    # materialize in the example the fact that additional properties can be added
+                    ret['...'] = '...'
+                return ret
         if method and 'properties' in schema and \
                 all(v.get('readOnly', False)
                     for v in schema['properties'].values()):
@@ -146,8 +152,14 @@ def _parse_schema(schema, method):
             if result != _READONLY_PROPERTY:
                 results.append((name, result))
 
+        if schema.get('additionalProperties', False):
+            # materialize in the example the fact that additional properties can be added
+            results.append(("...", "..."))
+
         return collections.OrderedDict(results)
 
+    if 'example' in schema:
+        return schema['example']
     if (schema_type, schema.get('format')) in _TYPE_MAPPING:
         return _TYPE_MAPPING[(schema_type, schema.get('format'))]
 
@@ -305,22 +317,64 @@ def _httpresource(endpoint, method, properties, convert, render_examples,
         yield '{indent}**DEPRECATED**'.format(**locals())
         yield ''
 
+    if 'security' in properties:
+        for sec_schema in properties['security']:
+            sec_scope = ' or '.join([
+                '``{}``'.format(s) for sch in sec_schema.values() for s in sch
+            ])
+            yield '{indent}**Scope required**: {sec_scope}'.format(**locals())
+        yield ''
+
+    def get_desc(desc, schema, indent, deep=True):
+        if entities:
+            doc = next(_process_one(['R'], schema, False, entities, convert))
+            if desc:
+                if not desc[-1] == '.':
+                    desc = desc + '.'
+            if doc[1]:
+                if not doc[1].startswith("Object of") and not doc[1].startswith("Array of"):
+                    doc[1] = "Object of type " + doc[1]
+                if not doc[1][-1] == '.':
+                    doc[1] = doc[1] + '.'
+                desc += '\n' + doc[1]
+            if deep and doc[2] and doc[2] != 'Additional properties':
+                if not doc[2][-1] == '.':
+                    doc[2] = doc[2] + '.'
+                desc += '\n' + doc[2]
+            desc = desc.rstrip()
+        else:
+            doc = next(_process_one(['R'], schema, False, entities, convert))
+            if desc:
+                if not desc[-1] == '.':
+                    desc = desc + '.'
+            if doc[2] and doc[2] != 'Additional properties':
+                if not doc[2][-1] == '.':
+                    doc[2] = doc[2] + '.'
+                desc += '\n' + doc[2]
+            desc = desc.rstrip()
+        desc = textwrap.indent(desc, '{indent}{indent}'.format(**locals())).lstrip()
+        return desc
+
     # print request's path params
     for param in filter(lambda p: p['in'] == 'path', parameters):
         yield indent + ':param {type} {name}:'.format(
             type=param['schema']['type'],
             name=param['name'])
 
-        for line in convert(param.get('description', '')).splitlines():
-            yield '{indent}{indent}{line}'.format(**locals())
+        desc = param.get('description', '')
+        desc = get_desc(desc, param['schema'], indent)
+        if desc:
+            yield '{indent}{indent}{desc}'.format(**locals())
 
     # print request's query params
     for param in filter(lambda p: p['in'] == 'query', parameters):
         yield indent + ':query {type} {name}:'.format(
             type=param['schema']['type'],
             name=param['name'])
-        for line in convert(param.get('description', '')).splitlines():
-            yield '{indent}{indent}{line}'.format(**locals())
+        desc = param.get('description', '')
+        desc = get_desc(desc, param['schema'], indent)
+        if desc:
+            yield '{indent}{indent}{desc}'.format(**locals())
         if param.get('required', False):
             yield '{indent}{indent}(Required)'.format(**locals())
         example = _parse_schema(param['schema'], method)
@@ -334,26 +388,6 @@ def _httpresource(endpoint, method, properties, convert, render_examples,
         else:
             query_param_examples.append((param['name'], example))
 
-    def get_desc(desc, schema, indent):
-        if entities:
-            doc = next(_process_one(['R'], schema, False, entities, convert))
-            if desc:
-                if not desc[-1] == '.':
-                    desc = desc + '.'
-            if doc[1]:
-                if not doc[1].startswith("Object of") and not doc[1].startswith("Array of"):
-                    doc[1] = "Object of type " + doc[1]
-                if not doc[1][-1] == '.':
-                    doc[1] = doc[1] + '.'
-                desc += '\n' + doc[1]
-            if doc[2]:
-                if not doc[2][-1] == '.':
-                    doc[2] = doc[2] + '.'
-                desc += '\n' + doc[2]
-            desc = desc.rstrip()
-        desc = textwrap.indent(desc, '{indent}{indent}'.format(**locals())).lstrip()
-        return desc
-
     # print request content
     if render_request:
         request_content = properties.get('requestBody', {}).get('content', {})
@@ -375,7 +409,7 @@ def _httpresource(endpoint, method, properties, convert, render_examples,
         if request_content and 'application/json' in request_content:
             schema = request_content['application/json'].get('schema', {})
             if '$entity_ref' in schema or schema.get('type', 'object') == 'array':
-                desc = get_desc(desc, schema, indent)
+                desc = get_desc(desc, schema, indent, deep=False)
                 if desc:
                     yield '{indent}:form body: {desc}'.format(**locals())
             else:
@@ -391,8 +425,10 @@ def _httpresource(endpoint, method, properties, convert, render_examples,
     reqheader_examples = {}
     for param in filter(lambda p: p['in'] == 'header', parameters):
         yield indent + ':reqheader {name}:'.format(**param)
-        for line in convert(param.get('description', '')).splitlines():
-            yield '{indent}{indent}{line}'.format(**locals())
+        desc = param.get('description', '')
+        desc = get_desc(desc, param['schema'], indent)
+        if desc:
+            yield '{indent}{indent}{desc}'.format(**locals())
         if param.get('required', False):
             yield '{indent}{indent}(Required)'.format(**locals())
         ex = param.get('example', param.get('schema', {}).get('example', None))
@@ -424,8 +460,10 @@ def _httpresource(endpoint, method, properties, convert, render_examples,
     for status, response in responses.items():
         for headername, header in response.get('headers', {}).items():
             yield indent + ':resheader {name}:'.format(name=headername)
-            for line in convert(header['description']).splitlines():
-                yield '{indent}{indent}{line}'.format(**locals())
+            desc = header.get('description', '')
+            desc = get_desc(desc, header.get('schema', {}), indent)
+            if desc:
+                yield '{indent}{indent}{desc}'.format(**locals())
             ex = header.get('example', header.get('schema', {}).get('example', None))
             if ex is None:
                 # try examples
@@ -436,16 +474,18 @@ def _httpresource(endpoint, method, properties, convert, render_examples,
     # print response status codes
     for status, response in responses.items():
         yield '{indent}:status {status}:'.format(**locals())
-        if entities:
-            content = response.get('content', {})
-            if content and 'application/json' in content:
-                schema = content['application/json']['schema']
-                desc = response.get('description', '')
-                desc = get_desc(desc, schema, indent)
-                if desc:
-                    yield '{indent}{indent}{desc}'.format(**locals())
+        content = response.get('content', {})
+        if entities and content and 'application/json' in content:
+            schema = content['application/json']['schema']
+            desc = response.get('description', '')
+            desc = get_desc(desc, schema, indent, deep=False)
+            if desc:
+                yield '{indent}{indent}{desc}'.format(**locals())
         else:
-            for line in convert(response['description']).splitlines():
+            desc = response.get('description', '')
+            if desc and desc[-1] != '.':
+                desc += '.'
+            for line in convert(desc.splitlines()):
                 yield '{indent}{indent}{line}'.format(**locals())
 
         # print response example
